dwca.terms package
==================

This module corresponds to the "property" type terms defined in https://dwc.tdwg.org/list/#31-index-by-term-name, excluding the deprecated ones. These Python classes represent a field in a data file (core or extension) in a Darwin Core Archive.

Field Class
-----------

.. automodule:: dwca.terms.field
   :members:
   :undoc-members:
   :show-inheritance:

OutsideTerm Class
-----------------

This is a special class, and its idea is to represent any field that is not defined in the standard.

.. automodule:: dwca.terms.outside_term
   :members:
   :undoc-members:
   :show-inheritance:

ChronometricAge module
----------------------

Extracted from the terms defined in https://chrono.tdwg.org/list/#4-vocabulary

.. automodule:: dwca.terms.chronometric_age
   :members:
   :undoc-members:
   :show-inheritance:

Event module
------------

.. automodule:: dwca.terms.event
   :members:
   :undoc-members:
   :show-inheritance:



GeologicalContext module
------------------------

.. automodule:: dwca.terms.geological_context
   :members:
   :undoc-members:
   :show-inheritance:

Identification module
---------------------

.. automodule:: dwca.terms.identification
   :members:
   :undoc-members:
   :show-inheritance:

Location module
---------------

.. automodule:: dwca.terms.location
   :members:
   :undoc-members:
   :show-inheritance:

MaterialEntity module
---------------------

.. automodule:: dwca.terms.material_entity
   :members:
   :undoc-members:
   :show-inheritance:

MaterialSample module
---------------------

.. automodule:: dwca.terms.material_sample
   :members:
   :undoc-members:
   :show-inheritance:

MeasurementOrFact module
------------------------

.. automodule:: dwca.terms.measurement_or_fact
   :members:
   :undoc-members:
   :show-inheritance:

Occurrence module
-----------------

.. automodule:: dwca.terms.occurrence
   :members:
   :undoc-members:
   :show-inheritance:

Organism module
---------------

.. automodule:: dwca.terms.organism
   :members:
   :undoc-members:
   :show-inheritance:

RecordLevel module
------------------

.. automodule:: dwca.terms.record_level
   :members:
   :undoc-members:
   :show-inheritance:

ResourceRelationship module
---------------------------

.. automodule:: dwca.terms.resource_relationship
   :members:
   :undoc-members:
   :show-inheritance:

Taxon module
------------

.. automodule:: dwca.terms.taxon
   :members:
   :undoc-members:
   :show-inheritance:
